@@ -383,6 +383,26 @@ I<Since C<0.01>>
 
 =back
 
+=over 4
+
+=item evaluate example 2
+
+  package main;
+
+  use Venus::Replace;
+
+  my $replace = Venus::Replace->new(
+    string => 'hello world',
+    regexp => 'world)(',
+    substr => 'universe',
+  );
+
+  my $evaluate = $replace->evaluate;
+
+  # Exception! Venus::Replace::Error (isa Venus::Error)
+
+=back
+
 =cut
 
 =head2 explain
